podman

package
v0.4.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2026 License: Apache-2.0, BSD-3-Clause, MIT Imports: 18 Imported by: 0

Documentation

Overview

Package podman extracts container inventory from podman database.

Index

Constants

const (
	// Name is the unique name of this extractor.
	Name = "containers/podman"
)

Variables

This section is empty.

Functions

func New

New returns a podman container inventory extractor.

Types

type Extractor

type Extractor struct {
	IncludeStopped bool
}

Extractor extracts containers from the podman db file.

func (Extractor) Extract

Extract container inventory through the podman db file passed as the scan input.

func (Extractor) FileRequired

func (e Extractor) FileRequired(api filesystem.FileAPI) bool

FileRequired returns true if the specified file matches podman db file pattern.

func (Extractor) Name

func (e Extractor) Name() string

Name of the extractor.

func (Extractor) Requirements

func (e Extractor) Requirements() *plugin.Capabilities

Requirements of the extractor.

func (Extractor) Version

func (e Extractor) Version() int

Version of the extractor.

type Metadata

type Metadata struct {
	ExposedPorts map[uint16][]string
	PID          int
	NameSpace    string
	StartedTime  time.Time
	FinishedTime time.Time
	Status       string
	ExitCode     int32
	Exited       bool
}

Metadata contains podman inventory metadata

func ToStruct added in v0.4.2

func ToStruct(m *pb.PodmanMetadata) *Metadata

ToStruct converts the PodmanMetadata proto to a Metadata struct.

func (*Metadata) SetProto added in v0.4.2

func (m *Metadata) SetProto(p *pb.Package)

SetProto sets the PodmanMetadata field in the Package proto.

Jump to