opam

package
v0.4.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2026 License: Apache-2.0, BSD-3-Clause, MIT Imports: 12 Imported by: 0

Documentation

Overview

Package opam extracts OCaml packages from opam install files.

Index

Constants

const (
	// Name is the unique name of this extractor.
	Name = "ocaml/opam"
)

Variables

This section is empty.

Functions

func New

New returns a new instance of the extractor.

func ParseInstall

func ParseInstall(ctx context.Context, r io.Reader) ([]*extractor.Package, error)

ParseInstall parses an opam install file or opam list output.

Types

type Extractor

type Extractor struct{}

Extractor extracts OCaml packages from opam install files.

func (Extractor) Extract

Extract extracts packages from the opam install file.

func (Extractor) FileRequired

func (e Extractor) FileRequired(api filesystem.FileAPI) bool

FileRequired returns true if the file path matches opam install files.

func (Extractor) Name

func (e Extractor) Name() string

Name of the extractor.

func (Extractor) Requirements

func (e Extractor) Requirements() *plugin.Capabilities

Requirements of the extractor.

func (Extractor) Version

func (e Extractor) Version() int

Version of the extractor.

Jump to