chocolatey

package
v0.4.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2026 License: Apache-2.0, BSD-3-Clause, MIT Imports: 13 Imported by: 0

Documentation

Overview

Package chocolatey extracts installed binaries from .nuspec files.

Index

Constants

const (
	// Name is the unique name of this extractor.
	Name = "os/chocolatey"
)

Variables

This section is empty.

Functions

func New

New returns a chocolatey extractor.

Types

type ChocoModule

type ChocoModule struct {
	XMLName  xml.Name `xml:"package"`
	Metadata Metadata `xml:"metadata"`
}

ChocoModule xml parser struct for .nuspec file

type Extractor

type Extractor struct {
	// contains filtered or unexported fields
}

Extractor extracts chocolatey packages from .nuspec file.

func (Extractor) Extract

Extract extracts chocolatey info from .nuspec files passed through the scan input.

func (Extractor) FileRequired

func (e Extractor) FileRequired(api filesystem.FileAPI) bool

FileRequired returns true if the specified file matches .nuspec file pattern.

func (Extractor) Name

func (e Extractor) Name() string

Name of the extractor.

func (Extractor) Requirements

func (e Extractor) Requirements() *plugin.Capabilities

Requirements of the extractor.

func (Extractor) Version

func (e Extractor) Version() int

Version of the extractor.

type Metadata

type Metadata struct {
	ID         string `xml:"id"`
	Version    string `xml:"version"`
	Authors    string `xml:"authors"`
	LicenseURL string `xml:"licenseUrl"`
	ProjectURL string `xml:"projectUrl"`
	Tags       string `xml:"tags"`
}

Metadata xml parser struct for metadata tag inside .nuspec file

Directories

Path Synopsis
Package metadata defines a Metadata struct for Chocolatey packages.
Package metadata defines a Metadata struct for Chocolatey packages.

Jump to