cos

package
v0.4.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2026 License: Apache-2.0, BSD-3-Clause, MIT Imports: 14 Imported by: 1

Documentation

Overview

Package cos extracts OS packages from Container Optimized OSes (go/cos).

Index

Constants

const (
	// Name is the unique name of this extractor.
	Name = "os/cos"
)

Variables

This section is empty.

Functions

func New added in v0.1.2

New returns a COS extractor.

For most use cases, initialize with: ``` e := New(&cpb.PluginConfig{}) ```

Types

type Extractor

type Extractor struct {
	Stats stats.Collector
	// contains filtered or unexported fields
}

Extractor extracts cos packages from cos database.

func (Extractor) Extract

Extract extracts packages from cos package info files passed through the scan input.

func (Extractor) FileRequired

func (e Extractor) FileRequired(api filesystem.FileAPI) bool

FileRequired returns true if the specified file matches cos package info file pattern.

func (Extractor) Name

func (e Extractor) Name() string

Name of the extractor.

func (Extractor) Requirements added in v0.1.3

func (e Extractor) Requirements() *plugin.Capabilities

Requirements of the extractor.

func (Extractor) Version

func (e Extractor) Version() int

Version of the extractor.

Directories

Path Synopsis
Package metadata defines a metadata struct for COS packages.
Package metadata defines a metadata struct for COS packages.

Jump to