Documentation
¶
Overview ¶
Package podman extracts container inventory from podman database.
Index ¶
Constants ¶
const (
// Name is the unique name of this extractor.
Name = "containers/podman"
)
Variables ¶
This section is empty.
Functions ¶
func New ¶
func New(cfg *cpb.PluginConfig) (filesystem.Extractor, error)
New returns a podman container inventory extractor.
Types ¶
type Extractor ¶
type Extractor struct {
IncludeStopped bool
}
Extractor extracts containers from the podman db file.
func (Extractor) Extract ¶
func (e Extractor) Extract(ctx context.Context, input *filesystem.ScanInput) (inventory.Inventory, error)
Extract container inventory through the podman db file passed as the scan input.
func (Extractor) FileRequired ¶
func (e Extractor) FileRequired(api filesystem.FileAPI) bool
FileRequired returns true if the specified file matches podman db file pattern.
func (Extractor) Requirements ¶
func (e Extractor) Requirements() *plugin.Capabilities
Requirements of the extractor.
type Metadata ¶
type Metadata struct {
ExposedPorts map[uint16][]string
PID int
NameSpace string
StartedTime time.Time
FinishedTime time.Time
Status string
ExitCode int32
Exited bool
}
Metadata contains podman inventory metadata
func ToStruct ¶ added in v0.4.2
func ToStruct(m *pb.PodmanMetadata) *Metadata
ToStruct converts the PodmanMetadata proto to a Metadata struct.
Click to show internal directories.
Click to hide internal directories.